==> ampache-7.4.2-2-any.pkg.tar.zst: usr/share/webapps/ampache/src/Repository/Model/Media.php <==
<?php

declare(strict_types=0);

/**
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright Ampache.org, 2001-2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Ampache\Repository\Model;

/**
 * media Interface
 *
 * This defines how the media file classes should
 * work, this lists all required functions and the expected
 * input
 */
interface Media
{
    /**
     * get_stream_types
     *
     * Returns an array of strings
     * 'native' = can be streamed natively
     * 'transcode' = transcode required
     * @param string $player
     */
    public function get_stream_types($player = null): array;

    /**
     * play_url
     *
     * Returns the url to stream the specified object
     * @param string $additional_params
     * @param string $player
     * @param bool $local
     */
    public function play_url($additional_params = '', $player = '', $local = false): string;

    /**
     * get_stream_name
     * Get the complete name to display for the stream.
     */
    public function get_stream_name(): string;

    /**
     * get_transcode_settings
     *
     * Should only be called if 'transcode' was returned by get_stream_types
     * Returns a raw transcode command for this item; the optional target
     * parameter can be used to request a specific format instead of the
     * default from the configuration file.
     * @param string|null $target
     * @param string|null $player
     * @param array{bitrate?: float|int, maxbitrate?: int, subtitle?: string, resolution?: string, quality?: int, frame?: float, duration?: float} $options
     * @return array{format?: string, command?: string}
     */
    public function get_transcode_settings(?string $target = null, ?string $player = null, array $options = []): array;

    /**
     * getYear
     */
    public function getYear(): string;

    /**
     * @param array{
     *      latitude?: float,
     *      longitude?: float,
     *      name?: string
     *  } $location
     */
    public function set_played(int $user_id, string $agent, array $location, int $date): bool;

    /**
     * @param int $user
     * @param string $agent
     * @param int $date
     */
    public function check_play_history($user, $agent, $date): bool;

    /**
     * remove
     * Delete the object from disk and/or database where applicable.
     */
    public function remove(): bool;

    /**
     * Returns the full/formatted name of the media items artist/author
     */
    public function get_artist_fullname(): string;

    /**
     * Returns the filename of the media-item
     */
    public function getFileName(): string;

    /**
     * Returns the media-type of the library-item
     */
    public function getMediaType(): LibraryItemEnum;
}

==> ampache-7.5.0-1-any.pkg.tar.zst: usr/share/webapps/ampache/src/Repository/Model/Media.php <==
<?php

declare(strict_types=0);

/**
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright Ampache.org, 2001-2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Ampache\Repository\Model;

/**
 * media Interface
 *
 * This defines how the media file classes should
 * work, this lists all required functions and the expected
 * input
 */
interface Media
{
    /**
     * get_stream_types
     *
     * Returns an array of strings
     * 'native' = can be streamed natively
     * 'transcode' = transcode required
     * @return list<string>
     */
    public function get_stream_types(?string $player = null): array;

    /**
     * play_url
     *
     * Returns the url to stream the specified object
     * @param string $additional_params
     * @param string $player
     * @param bool $local
     */
    public function play_url($additional_params = '', $player = '', $local = false): string;

    /**
     * get_stream_name
     * Get the complete name to display for the stream.
     */
    public function get_stream_name(): string;

    /**
     * get_transcode_settings
     *
     * Should only be called if 'transcode' was returned by get_stream_types
     * Returns a raw transcode command for this item; the optional target
     * parameter can be used to request a specific format instead of the
     * default from the configuration file.
     * @param string|null $target
     * @param string|null $player
     * @param array{bitrate?: float|int, maxbitrate?: int, subtitle?: string, resolution?: string, quality?: int, frame?: float, duration?: float} $options
     * @return array{format?: string, command?: string}
     */
    public function get_transcode_settings(?string $target = null, ?string $player = null, array $options = []): array;

    /**
     * getYear
     */
    public function getYear(): string;

    /**
     * @param array{
     *      latitude?: float,
     *      longitude?: float,
     *      name?: string
     *  } $location
     */
    public function set_played(int $user_id, string $agent, array $location, int $date): bool;

    /**
     * @param int $user
     * @param string $agent
     * @param int $date
     */
    public function check_play_history($user, $agent, $date): bool;

    /**
     * remove
     * Delete the object from disk and/or database where applicable.
     */
    public function remove(): bool;

    /**
     * Returns the full/formatted name of the media items artist/author
     */
    public function get_artist_fullname(): string;

    /**
     * Returns the filename of the media-item
     */
    public function getFileName(): string;

    /**
     * Returns the media-type of the library-item
     */
    public function getMediaType(): LibraryItemEnum;
}
